@@ -47,8 +47,8 @@ class function():
 class MainWindow(QMainWindow):
     def __init__(self,x,y,weights,local_variables):
         QMainWindow.__init__(self)
-        this_directory = Path(__file__).parent
 
+        this_directory = Path(__file__).parent
         self.ui = loadUiWidget(this_directory / "pycftoolGUI.ui")
         self.setCentralWidget(self.ui)
 
@@ -533,7 +533,7 @@ class MainWindow(QMainWindow):
         self.rmse()
         self.chiSquared()
 
-def pyCftool(x=None, y=None, weights=None,local_vars = {}):
+def cftool(x=None, y=None, weights=None,local_vars = {}):
     if len(local_vars) != 0:
         for item in list(local_vars):
             if not isinstance(local_vars[item],np.ndarray):
